@@ -6,7 +6,7 @@ use Carp ();
 
 use vars qw($VERSION);
 
-$VERSION='1.01';
+$VERSION='1.01';  # $Date: 2003/10/14 18:48:59 $
 
 my %form_tags = map {$_ => 1} qw(input textarea button select option);
 
@@ -124,6 +124,7 @@ sub parse
 		last if $tag eq "/form";
 		if ($tag eq "input") {
 		    my $type = delete $attr->{type} || "text";
+		    $attr->{value_name} = $p->get_phrase;
 		    $f->push_input($type, $attr);
 		} elsif ($tag eq "textarea") {
 		    $attr->{textarea_value} = $attr->{value}
@@ -270,11 +271,15 @@ sub inputs
 }
 
 
-=item $input = $form->find_input($name, $type, $index)
+=item $input = $form->find_input( $name )
 
-This method is used to locate some specific input within the form.  At
-least one of the arguments must be defined.  If no matching input is
-found, C<undef> is returned.
+=item $input = $form->find_input( $name, $type )
+
+=item $input = $form->find_input( $name, $type, $index )
+
+This method is used to locate specific inputs within the form.  All
+inputs that match the arguments given are returned.  In scalar context
+only the first is returned, or C<undef> if none match.
 
 If $name is specified, then the input must have the indicated name.
 
@@ -291,17 +296,35 @@ input with the given name and/or type.
 sub find_input
 {
     my($self, $name, $type, $no) = @_;
-    $no ||= 1;
-    for (@{$self->{'inputs'}}) {
-	if (defined $name) {
-	    next unless exists $_->{name};
-	    next if $name ne $_->{name};
+    if (wantarray) {
+	my @res;
+	my $c;
+	for (@{$self->{'inputs'}}) {
+	    if (defined $name) {
+		next unless exists $_->{name};
+		next if $name ne $_->{name};
+	    }
+	    next if $type && $type ne $_->{type};
+	    $c++;
+	    next if $no && $no != $c;
+	    push(@res, $_);
 	}
-	next if $type && $type ne $_->{type};
-	next if --$no;
-	return $_;
+	return @res;
+	
+    }
+    else {
+	$no ||= 1;
+	for (@{$self->{'inputs'}}) {
+	    if (defined $name) {
+		next unless exists $_->{name};
+		next if $name ne $_->{name};
+	    }
+	    next if $type && $type ne $_->{type};
+	    next if --$no;
+	    return $_;
+	}
+	return undef;
     }
-    return undef;
 }
 
 sub fixup
@@ -770,12 +793,16 @@ sub dump
 
     $type = ($type eq "text") ? "" : " ($type)";
     my $menu = $self->{menu} || "";
+    my $value_names = $self->{value_names};
     if ($menu) {
 	my @menu;
 	for (0 .. @$menu-1) {
 	    my $opt = $menu->[$_];
 	    $opt = "<UNDEF>" unless defined $opt;
 	    substr($opt,0,0) = "*" if $self->{seen}[$_];
+	    $opt .= "/$value_names->[$_]"
+		if $value_names && defined $value_names->[$_]
+		    && $value_names->[$_] ne $opt;
 	    push(@menu, $opt);
 	}
 	$menu = "[" . join("|", @menu) . "]";
@@ -923,11 +950,15 @@ sub value
 		}
 		unless (defined $cur) {
 		    $cur = $cur_ignorecase;
-		    Carp::croak("Illegal value '$val'") unless defined $cur;
+		    unless (defined $cur) {
+			my $n = $self->name;
+		        Carp::croak("Illegal value '$val' for field '$n'");
+		    }
 		}
 	    }
 	    else {
-	        Carp::croak("Can't turn this input off");
+		my $n = $self->name;
+	        Carp::croak("The '$n' field can't be unchecked");
 	    }
 	}
 	$self->{current} = $cur;
