@@ -1,4 +1,4 @@
-# $Id: UserAgent.pm,v 2.4 2003/02/04 16:36:55 gisle Exp $
+# $Id: UserAgent.pm,v 2.6 2003/10/14 18:20:17 gisle Exp $
 
 package LWP::UserAgent;
 use strict;
@@ -117,7 +117,7 @@ use vars qw(@ISA $VERSION);
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
-$VERSION = sprintf("%d.%03d", q$Revision: 2.4 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%03d", q$Revision: 2.6 $ =~ /(\d+)\.(\d+)/);
 
 use HTTP::Request ();
 use HTTP::Response ();
@@ -267,7 +267,7 @@ sub _request_sanity_check {
 }
 
 
-=item $ua->send_request($request, $arg [, $size])
+=item $ua->send_request($request, [$arg [, $size]])
 
 This method dispatches a single WWW request on behalf of a user, and
 returns the response received.  The request is sent off unmodified,
@@ -346,7 +346,16 @@ sub send_request
       $protocol = eval { LWP::Protocol::create($scheme, $self) };
       if ($@) {
 	$@ =~ s/ at .* line \d+.*//s;  # remove file/line number
-	return _new_response($request, &HTTP::Status::RC_NOT_IMPLEMENTED, $@);
+	my $response =  _new_response($request, &HTTP::Status::RC_NOT_IMPLEMENTED, $@);
+	if ($scheme eq "https") {
+	    $response->message($response->message . " (Crypt::SSLeay not installed)");
+	    $response->content_type("text/plain");
+	    $response->content(<<EOT);
+LWP will support https URLs if the Crypt::SSLeay module is installed.
+More information at <http://www.linpro.no/lwp/libwww-perl/README.SSL>.
+EOT
+	}
+	return $response;
       }
     }
 
